;; Generated package description from satchel.el  -*- no-byte-compile: t -*-
(define-package "satchel" "0.2" "A bag for your files, separated by git branches" '((emacs "27.2") (project "0.8.1")) :commit "6e5613e203f6937202cb5d55249e7e6be939067b" :url "https://elpa.gnu.org/packages/satchel.html" :authors '(("Theodor Thornhill" . "theo@thornhill.no")) :maintainer '("Theodor Thornhill" . "theo@thornhill.no") :keywords '("tools" "languages"))
